==> cfactor-1.5.3.tar.gz: cfactor-1.5.3/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-


try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


# with open('README.rst') as readme_file:
#     readme = readme_file.read()

# with open('HISTORY.rst') as history_file:
#     history = history_file.read()

requirements = [
'matplotlib==3.0.2',
'PyQt5==5.11.3',
'pyqtgraph==0.10.0',
# 'xlrd>=1.1.0',
# 'openpyxl>=2.5.11',
'python-docx==0.8.7'
]

test_requirements = [
    # TODO: put package test requirements here
]

setup(
    name='cfactor',
    version='1.5.3',
    description="Program to calculate earthquake factor acording to 2800 v4",
    # long_description=readme + '\n\n' + history,
    author="Raeyat Ebrahim",
    author_email='ebe79442114@yahoo.com',
    url='https://github.com/ebrahimraeyat/civiltools',
    packages=[
        '.',
    ],
    package_dir={'.':
                 '.'},
    include_package_data=True,
    # install_requires=requirements,
    license = "GPL-3.0",
    zip_safe=False,
    keywords='cfactor',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Natural Language :: Persian',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    test_suite='tests',
    tests_require=test_requirements
)


# from __future__ import print_function
# from setuptools import setup, find_packages
# from setuptools.command.test import test as TestCommand
# import io
# import codecs
# import os
# import sys

# import records

# here = os.path.abspath(os.path.dirname(__file__))

# def read(*filenames, **kwargs):
#     encoding = kwargs.get('encoding', 'utf-8')
#     sep = kwargs.get('sep', '\n')
#     buf = []
#     for filename in filenames:
#         with io.open(filename, encoding=encoding) as f:
#             buf.append(f.read())
#     return sep.join(buf)

# long_description = read('README.txt', 'CHANGES.txt')

# class PyTest(TestCommand):
#     def finalize_options(self):
#         TestCommand.finalize_options(self)
#         self.test_args = []
#         self.test_suite = True

#     def run_tests(self):
#         import pytest
#         errcode = pytest.main(self.test_args)
#         sys.exit(errcode)

# setup(
#     name='sandman',
#     version=records.__version__,
#     url='http://github.com/jeffknupp/sandman/',
#     license='Apache Software License',
#     author='Jeff Knupp',
#     tests_require=['pytest'],
#     install_requires=['Flask>=0.10.1',
#                     'Flask-SQLAlchemy>=1.0',
#                     'SQLAlchemy==0.8.2',
#                     ],
#     cmdclass={'test': PyTest},
#     author_email='jeff@jeffknupp.com',
#     description='Automated REST APIs for existing database-driven systems',
#     long_description=long_description,
#     packages=['sandman'],
#     include_package_data=True,
#     platforms='any',
#     test_suite='sandman.test.test_sandman',
#     classifiers = [
#         'Programming Language :: Python',
#         'Development Status :: 4 - Beta',
#         'Natural Language :: English',
#         'Environment :: Web Environment',
#         'Intended Audience :: Developers',
#         'License :: OSI Approved :: Apache Software License',
#         'Operating System :: OS Independent',
#         'Topic :: Software Development :: Libraries :: Python Modules',
#         'Topic :: Software Development :: Libraries :: Application Frameworks',
#         'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
#         ],
#     extras_require={
#         'testing': ['pytest'],
#     }
# )

==> cfactor-1.5.4.tar.gz: cfactor-1.5.4/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-


try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


# with open('README.rst') as readme_file:
#     readme = readme_file.read()

# with open('HISTORY.rst') as history_file:
#     history = history_file.read()

requirements = [
'matplotlib==3.0.2',
'PyQt5==5.11.3',
'pyqtgraph==0.10.0',
# 'xlrd>=1.1.0',
# 'openpyxl>=2.5.11',
'python-docx==0.8.7'
]

test_requirements = [
    # TODO: put package test requirements here
]

setup(
    name='cfactor',
    version='1.5.4',
    description="Program to calculate earthquake factor acording to 2800 v4",
    # long_description=readme + '\n\n' + history,
    author="Raeyat Ebrahim",
    author_email='ebe79442114@yahoo.com',
    url='https://github.com/ebrahimraeyat/civiltools',
    packages=[
        'cfactor',
    ],
    package_dir={'cfactor':
                 'cfactor'},
    include_package_data=True,
    install_requires=requirements,
    license = "GPL-3.0",
    zip_safe=False,
    keywords='cfactor',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Natural Language :: Persian',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    test_suite='tests',
    tests_require=test_requirements
)


# from __future__ import print_function
# from setuptools import setup, find_packages
# from setuptools.command.test import test as TestCommand
# import io
# import codecs
# import os
# import sys

# import records

# here = os.path.abspath(os.path.dirname(__file__))

# def read(*filenames, **kwargs):
#     encoding = kwargs.get('encoding', 'utf-8')
#     sep = kwargs.get('sep', '\n')
#     buf = []
#     for filename in filenames:
#         with io.open(filename, encoding=encoding) as f:
#             buf.append(f.read())
#     return sep.join(buf)

# long_description = read('README.txt', 'CHANGES.txt')

# class PyTest(TestCommand):
#     def finalize_options(self):
#         TestCommand.finalize_options(self)
#         self.test_args = []
#         self.test_suite = True

#     def run_tests(self):
#         import pytest
#         errcode = pytest.main(self.test_args)
#         sys.exit(errcode)

# setup(
#     name='sandman',
#     version=records.__version__,
#     url='http://github.com/jeffknupp/sandman/',
#     license='Apache Software License',
#     author='Jeff Knupp',
#     tests_require=['pytest'],
#     install_requires=['Flask>=0.10.1',
#                     'Flask-SQLAlchemy>=1.0',
#                     'SQLAlchemy==0.8.2',
#                     ],
#     cmdclass={'test': PyTest},
#     author_email='jeff@jeffknupp.com',
#     description='Automated REST APIs for existing database-driven systems',
#     long_description=long_description,
#     packages=['sandman'],
#     include_package_data=True,
#     platforms='any',
#     test_suite='sandman.test.test_sandman',
#     classifiers = [
#         'Programming Language :: Python',
#         'Development Status :: 4 - Beta',
#         'Natural Language :: English',
#         'Environment :: Web Environment',
#         'Intended Audience :: Developers',
#         'License :: OSI Approved :: Apache Software License',
#         'Operating System :: OS Independent',
#         'Topic :: Software Development :: Libraries :: Python Modules',
#         'Topic :: Software Development :: Libraries :: Application Frameworks',
#         'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
#         ],
#     extras_require={
#         'testing': ['pytest'],
#     }
# )
